@@ -1,11 +1,12 @@
 use Dist::Iller::Standard;
 
-our $VERSION = '0.0100'; # VERSION:
 # PODNAME: Dist::Iller::Config::Author::CSSON
 # ABSTRACT: Dist::Iller config for Csson
 
 class Dist::Iller::Config::Author::CSSON using Moose with Dist::Iller::Role::Config {
 
+    our $VERSION = '0.0101'; # VERSION
+
     use Path::Tiny;
 
     has filepath => (
@@ -42,6 +43,11 @@ class Dist::Iller::Config::Author::CSSON using Moose with Dist::Iller::Role::Con
         isa => Int,
         default => 0,
     );
+    has travis => (
+        is => 'rw',
+        isa => Int,
+        default => 1,
+    );
 
     method _build_homepage {
         return sprintf 'https://metacpan.org/release/' . $self->distribution_name;
@@ -55,7 +61,7 @@ class Dist::Iller::Config::Author::CSSON using Moose with Dist::Iller::Role::Con
         return !$ENV{'FAKE_RELEASE'} && $self->is_private ? 1 : 0;
     }
     method is_cpan_release {
-        return !$ENV{'FAKE_RELEASE'} && $self->is_private ? 0 : 1;
+        return $ENV{'FAKE_RELEASE'} || $self->is_private ? 0 : 1;
     }
     method add_default_github {
         # check git config
@@ -88,12 +94,12 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config for Csson
 
 =head1 VERSION
 
-Version 0.0100, released 2015-11-24.
+Version 0.0101, released 2016-01-09.
 
 =head1 SYNOPSIS
 
     # in iller.yaml
-    + config: Author::CSSON
+    +config: Author::CSSON
 
 =head1 DESCRIPTION
 
